@@ -1,5 +1,5 @@
 from tuneconfig.config_factory import ConfigFactory, grid_search
 from tuneconfig.experiment import Experiment
 from tuneconfig.analysis import ExperimentAnalysis
-from tuneconfig.plotting import ExperimentPlotter
+from tuneconfig.plotter import ExperimentPlotter
 from tuneconfig.launcher import run_experiment
